@@ -1,5 +1,3 @@
-from __future__ import annotations
-
 from dataclasses import dataclass
 from enum import Enum
 from typing import Optional
@@ -19,13 +17,24 @@ class Source(Enum):
 @dataclass_json
 @dataclass
 class TelescopeBaseType:
+    """
+    Base class for all top-level Telescope entities.
+    """
     id: str
-    source: Source
-    version: int
     created_at: str
     updated_at: str
 
 
+@dataclass_json
+@dataclass
+class IngestedDataType(TelescopeBaseType):
+    """
+    Base data type for entities which are ingested from external sources (e.g. PDL, RevenueBase, etc.)
+    """
+    source: Source
+    version: int
+
+
 @dataclass_json
 @dataclass
 class Location:
@@ -37,7 +46,7 @@ class Location:
     city: Optional[str] = None
 
     @staticmethod
-    def from_pdl(pdl_input: dict[str, any]) -> Optional[Location]:
+    def from_pdl(pdl_input: dict[str, any]) -> Optional['Location']:
         country = pdl_input.get('country')
         return Location(
             line_1=pdl_input.get('street_address'),
