@@ -18,7 +18,7 @@ class ExperienceCompany:
     name: Optional[str] = None
     linkedin_internal_id: Optional[str] = None
     linkedin_url: Optional[str] = None
-    location: Optional['Location'] = None
+    location: Optional[Location] = None
     website: Optional[str] = None
 
     @staticmethod
@@ -36,7 +36,7 @@ class ExperienceCompany:
 @dataclass_json
 @dataclass
 class Experience:
-    company: Optional['ExperienceCompany'] = None
+    company: Optional[ExperienceCompany] = None
     start_datetime: Optional[str] = None
     end_datetime: Optional[str] = None
     is_primary: Optional[bool] = None
@@ -69,7 +69,7 @@ class Degree:
 @dataclass_json
 @dataclass
 class Education:
-    degree: Optional['Degree'] = None
+    degree: Optional[Degree] = None
     institution_logo_url: Optional[str] = None
     institution_name: Optional[str] = None
     institution_linkedin_url: Optional[str] = None
@@ -128,10 +128,10 @@ class Person(IngestedDataType):
     job_last_updated: Optional[str] = None
     interests: Optional[list[str]] = None
     skills: Optional[list[str]] = None
-    experience: Optional[list['Experience']] = None
-    education: Optional[list['Education']] = None
-    languages: Optional[list['Language']] = None
-    location: Optional['Location'] = None
+    experience: Optional[list[Experience]] = None
+    education: Optional[list[Education]] = None
+    languages: Optional[list[Language]] = None
+    location: Optional[Location] = None
     tags: Optional[list[str]] = None
     uploaded_by_user_id: Optional[str] = None
     last_enriched_at: Optional[str] = None
